@@ -4,7 +4,7 @@
 
 ;; Author: Milan Glacier <dev@milanglacier.com>
 ;; Maintainer: Milan Glacier <dev@milanglacier.com>
-;; Version: 0.6.0
+;; Version: 0.7.0
 ;; URL: https://github.com/milanglacier/minuet-ai.el
 ;; Package-Requires: ((emacs "29") (plz "0.9") (dash "2.19.1"))
 
@@ -888,17 +888,15 @@ many lines.  Without a prefix argument, accept only the first line."
                                    (string-join remaining-lines "\n"))))
       (minuet--cleanup-suggestion)
       (insert (string-join selected-lines "\n"))
-      (if remaining-suggestion
-          (progn
-            (insert "\n") ;; There is a remaining suggestion, so move to the next line.
-            ;; NOTE: We do not need to worry about Minuet
-            ;; automatically triggering the next suggestion upon
-            ;; continuous acceptance.  Minuet only attempts
-            ;; auto-suggestion when the last command was not a Minuet
-            ;; command. Since we have just accepted partial lines, the
-            ;; last command is indeed a Minuet command.
-            (minuet--display-suggestion (list remaining-suggestion) 0))
-        (minuet--cleanup-suggestion)))))
+      (when remaining-suggestion
+        (insert "\n") ;; There is a remaining suggestion, so move to the next line.
+        ;; NOTE: We do not need to worry about Minuet
+        ;; automatically triggering the next suggestion upon
+        ;; continuous acceptance.  Minuet only attempts
+        ;; auto-suggestion when the last command was not a Minuet
+        ;; command. Since we have just accepted partial lines, the
+        ;; last command is indeed a Minuet command.
+        (minuet--display-suggestion (list remaining-suggestion) 0)))))
 
 ;;;###autoload
 (defun minuet-complete-with-minibuffer ()
